@@ -12,7 +12,7 @@ async def create_files(files: List[bytes] = File(...)):
 
 
 @app.post("/uploadfiles/")
-async def create_upload_files(files: List[UploadFile] = File(...)):
+async def create_upload_files(files: List[UploadFile]):
     return {"filenames": [file.filename for file in files]}
 
 
